# smolagents

[https://github.com/huggingface/smolagents](https://github.com/huggingface/smolagents)

## Default Agent Type

We use [`smolagents.ToolCallingAgent`](https://huggingface.co/docs/smolagents/reference/agents#smolagents.ToolCallingAgent) as default.
Check the reference to find additional supported `agent_args`.

## Default Model Type

We use [`any_llm`](https://mozilla-ai.github.io/any-llm/) as the default model provider.
Check the [AnyLLM documentation](https://mozilla-ai.github.io/any-llm/) for supported providers and `model_args`.

## Run args

Check [`smolagents.MultiStepAgent.run`](https://huggingface.co/docs/smolagents/main/en/reference/agents#smolagents.MultiStepAgent.run) to find additional supported `AnyAgent.run` args.
